@@ -1,7 +1,7 @@
 # flake8: noqa
 from .version import __version__
 
-from .bernstein import Bernstein
+from .bernstein import Bernstein, BernsteinFitter
 from .clock import Clock, GlobalClock
 from .crypt import Crypt
 from .dataframe_tools import (
@@ -29,6 +29,7 @@ import easier.hvtools as hv  # Need this weird import to make hv symbol work
 import easier.filtering as filtering
 from .nice_dates import nice_dates
 from .duck import Duck
+from .minimodel import MiniModel
 
 # Alias for nice_dates
 date_formatter = nice_dates
@@ -50,6 +51,7 @@ from .utils import (
     screen_width_full,
     BlobMixin,
     BlobAttr,
+    Scaler
 )
 
 # alias for ease of remembering the name
